==> kubernetes-model-admissionregistration-6.6.0-sources.jar: io/fabric8/kubernetes/api/model/admissionregistration/v1alpha1/ValidatingAdmissionPolicyBindingSpecFluentImpl.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ValidatingAdmissionPolicyBindingSpecFluentImpl<A extends ValidatingAdmissionPolicyBindingSpecFluent<A>> extends BaseFluent<A> implements ValidatingAdmissionPolicyBindingSpecFluent<A>{
  public ValidatingAdmissionPolicyBindingSpecFluentImpl() {
  }
  public ValidatingAdmissionPolicyBindingSpecFluentImpl(ValidatingAdmissionPolicyBindingSpec instance) {
    this.withMatchResources(instance.getMatchResources()); 
    this.withParamRef(instance.getParamRef()); 
    this.withPolicyName(instance.getPolicyName()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private MatchResourcesBuilder matchResources;
  private ParamRefBuilder paramRef;
  private String policyName;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildMatchResources instead.
   * @return The buildable object.
   */
  @Deprecated
  public MatchResources getMatchResources() {
    return this.matchResources!=null ?this.matchResources.build():null;
  }
  public MatchResources buildMatchResources() {
    return this.matchResources!=null ?this.matchResources.build():null;
  }
  public A withMatchResources(MatchResources matchResources) {
    _visitables.get("matchResources").remove(this.matchResources);
    if (matchResources!=null){ this.matchResources= new MatchResourcesBuilder(matchResources); _visitables.get("matchResources").add(this.matchResources);} else { this.matchResources = null; _visitables.get("matchResources").remove(this.matchResources); } return (A) this;
  }
  public Boolean hasMatchResources() {
    return this.matchResources != null;
  }
  public ValidatingAdmissionPolicyBindingSpecFluent.MatchResourcesNested<A> withNewMatchResources() {
    return new ValidatingAdmissionPolicyBindingSpecFluentImpl.MatchResourcesNestedImpl();
  }
  public ValidatingAdmissionPolicyBindingSpecFluent.MatchResourcesNested<A> withNewMatchResourcesLike(MatchResources item) {
    return new ValidatingAdmissionPolicyBindingSpecFluentImpl.MatchResourcesNestedImpl(item);
  }
  public ValidatingAdmissionPolicyBindingSpecFluent.MatchResourcesNested<A> editMatchResources() {
    return withNewMatchResourcesLike(getMatchResources());
  }
  public ValidatingAdmissionPolicyBindingSpecFluent.MatchResourcesNested<A> editOrNewMatchResources() {
    return withNewMatchResourcesLike(getMatchResources() != null ? getMatchResources(): new MatchResourcesBuilder().build());
  }
  public ValidatingAdmissionPolicyBindingSpecFluent.MatchResourcesNested<A> editOrNewMatchResourcesLike(MatchResources item) {
    return withNewMatchResourcesLike(getMatchResources() != null ? getMatchResources(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildParamRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public ParamRef getParamRef() {
    return this.paramRef!=null ?this.paramRef.build():null;
  }
  public ParamRef buildParamRef() {
    return this.paramRef!=null ?this.paramRef.build():null;
  }
  public A withParamRef(ParamRef paramRef) {
    _visitables.get("paramRef").remove(this.paramRef);
    if (paramRef!=null){ this.paramRef= new ParamRefBuilder(paramRef); _visitables.get("paramRef").add(this.paramRef);} else { this.paramRef = null; _visitables.get("paramRef").remove(this.paramRef); } return (A) this;
  }
  public Boolean hasParamRef() {
    return this.paramRef != null;
  }
  public A withNewParamRef(String name,String namespace) {
    return (A)withParamRef(new ParamRef(name, namespace));
  }
  public ValidatingAdmissionPolicyBindingSpecFluent.ParamRefNested<A> withNewParamRef() {
    return new ValidatingAdmissionPolicyBindingSpecFluentImpl.ParamRefNestedImpl();
  }
  public ValidatingAdmissionPolicyBindingSpecFluent.ParamRefNested<A> withNewParamRefLike(ParamRef item) {
    return new ValidatingAdmissionPolicyBindingSpecFluentImpl.ParamRefNestedImpl(item);
  }
  public ValidatingAdmissionPolicyBindingSpecFluent.ParamRefNested<A> editParamRef() {
    return withNewParamRefLike(getParamRef());
  }
  public ValidatingAdmissionPolicyBindingSpecFluent.ParamRefNested<A> editOrNewParamRef() {
    return withNewParamRefLike(getParamRef() != null ? getParamRef(): new ParamRefBuilder().build());
  }
  public ValidatingAdmissionPolicyBindingSpecFluent.ParamRefNested<A> editOrNewParamRefLike(ParamRef item) {
    return withNewParamRefLike(getParamRef() != null ? getParamRef(): item);
  }
  public String getPolicyName() {
    return this.policyName;
  }
  public A withPolicyName(String policyName) {
    this.policyName=policyName; return (A) this;
  }
  public Boolean hasPolicyName() {
    return this.policyName != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ValidatingAdmissionPolicyBindingSpecFluentImpl that = (ValidatingAdmissionPolicyBindingSpecFluentImpl) o;
    if (matchResources != null ? !matchResources.equals(that.matchResources) :that.matchResources != null) return false;
    if (paramRef != null ? !paramRef.equals(that.paramRef) :that.paramRef != null) return false;
    if (policyName != null ? !policyName.equals(that.policyName) :that.policyName != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(matchResources,  paramRef,  policyName,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (matchResources != null) { sb.append("matchResources:"); sb.append(matchResources + ","); }
    if (paramRef != null) { sb.append("paramRef:"); sb.append(paramRef + ","); }
    if (policyName != null) { sb.append("policyName:"); sb.append(policyName + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class MatchResourcesNestedImpl<N> extends MatchResourcesFluentImpl<ValidatingAdmissionPolicyBindingSpecFluent.MatchResourcesNested<N>> implements ValidatingAdmissionPolicyBindingSpecFluent.MatchResourcesNested<N>,Nested<N>{
    MatchResourcesNestedImpl(MatchResources item) {
      this.builder = new MatchResourcesBuilder(this, item);
    }
    MatchResourcesNestedImpl() {
      this.builder = new MatchResourcesBuilder(this);
    }
    MatchResourcesBuilder builder;
    public N and() {
      return (N) ValidatingAdmissionPolicyBindingSpecFluentImpl.this.withMatchResources(builder.build());
    }
    public N endMatchResources() {
      return and();
    }
    
  }
  class ParamRefNestedImpl<N> extends ParamRefFluentImpl<ValidatingAdmissionPolicyBindingSpecFluent.ParamRefNested<N>> implements ValidatingAdmissionPolicyBindingSpecFluent.ParamRefNested<N>,Nested<N>{
    ParamRefNestedImpl(ParamRef item) {
      this.builder = new ParamRefBuilder(this, item);
    }
    ParamRefNestedImpl() {
      this.builder = new ParamRefBuilder(this);
    }
    ParamRefBuilder builder;
    public N and() {
      return (N) ValidatingAdmissionPolicyBindingSpecFluentImpl.this.withParamRef(builder.build());
    }
    public N endParamRef() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-admissionregistration-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/admissionregistration/v1alpha1/ValidatingAdmissionPolicyBindingSpecFluentImpl.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ValidatingAdmissionPolicyBindingSpecFluentImpl<A extends ValidatingAdmissionPolicyBindingSpecFluent<A>> extends BaseFluent<A> implements ValidatingAdmissionPolicyBindingSpecFluent<A>{
  public ValidatingAdmissionPolicyBindingSpecFluentImpl() {
  }
  public ValidatingAdmissionPolicyBindingSpecFluentImpl(ValidatingAdmissionPolicyBindingSpec instance) {
    if (instance != null) {
      this.withMatchResources(instance.getMatchResources());
      this.withParamRef(instance.getParamRef());
      this.withPolicyName(instance.getPolicyName());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private MatchResourcesBuilder matchResources;
  private ParamRefBuilder paramRef;
  private String policyName;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildMatchResources instead.
   * @return The buildable object.
   */
  @Deprecated
  public MatchResources getMatchResources() {
    return this.matchResources!=null ?this.matchResources.build():null;
  }
  public MatchResources buildMatchResources() {
    return this.matchResources!=null ?this.matchResources.build():null;
  }
  public A withMatchResources(MatchResources matchResources) {
    _visitables.get("matchResources").remove(this.matchResources);
    if (matchResources!=null){ this.matchResources= new MatchResourcesBuilder(matchResources); _visitables.get("matchResources").add(this.matchResources);} else { this.matchResources = null; _visitables.get("matchResources").remove(this.matchResources); } return (A) this;
  }
  public Boolean hasMatchResources() {
    return this.matchResources != null;
  }
  public ValidatingAdmissionPolicyBindingSpecFluentImpl.MatchResourcesNested<A> withNewMatchResources() {
    return new ValidatingAdmissionPolicyBindingSpecFluentImpl.MatchResourcesNestedImpl();
  }
  public ValidatingAdmissionPolicyBindingSpecFluentImpl.MatchResourcesNested<A> withNewMatchResourcesLike(MatchResources item) {
    return new ValidatingAdmissionPolicyBindingSpecFluentImpl.MatchResourcesNestedImpl(item);
  }
  public ValidatingAdmissionPolicyBindingSpecFluentImpl.MatchResourcesNested<A> editMatchResources() {
    return withNewMatchResourcesLike(getMatchResources());
  }
  public ValidatingAdmissionPolicyBindingSpecFluentImpl.MatchResourcesNested<A> editOrNewMatchResources() {
    return withNewMatchResourcesLike(getMatchResources() != null ? getMatchResources(): new MatchResourcesBuilder().build());
  }
  public ValidatingAdmissionPolicyBindingSpecFluentImpl.MatchResourcesNested<A> editOrNewMatchResourcesLike(MatchResources item) {
    return withNewMatchResourcesLike(getMatchResources() != null ? getMatchResources(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildParamRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public ParamRef getParamRef() {
    return this.paramRef!=null ?this.paramRef.build():null;
  }
  public ParamRef buildParamRef() {
    return this.paramRef!=null ?this.paramRef.build():null;
  }
  public A withParamRef(ParamRef paramRef) {
    _visitables.get("paramRef").remove(this.paramRef);
    if (paramRef!=null){ this.paramRef= new ParamRefBuilder(paramRef); _visitables.get("paramRef").add(this.paramRef);} else { this.paramRef = null; _visitables.get("paramRef").remove(this.paramRef); } return (A) this;
  }
  public Boolean hasParamRef() {
    return this.paramRef != null;
  }
  public A withNewParamRef(String name,String namespace) {
    return (A)withParamRef(new ParamRef(name, namespace));
  }
  public ValidatingAdmissionPolicyBindingSpecFluentImpl.ParamRefNested<A> withNewParamRef() {
    return new ValidatingAdmissionPolicyBindingSpecFluentImpl.ParamRefNestedImpl();
  }
  public ValidatingAdmissionPolicyBindingSpecFluentImpl.ParamRefNested<A> withNewParamRefLike(ParamRef item) {
    return new ValidatingAdmissionPolicyBindingSpecFluentImpl.ParamRefNestedImpl(item);
  }
  public ValidatingAdmissionPolicyBindingSpecFluentImpl.ParamRefNested<A> editParamRef() {
    return withNewParamRefLike(getParamRef());
  }
  public ValidatingAdmissionPolicyBindingSpecFluentImpl.ParamRefNested<A> editOrNewParamRef() {
    return withNewParamRefLike(getParamRef() != null ? getParamRef(): new ParamRefBuilder().build());
  }
  public ValidatingAdmissionPolicyBindingSpecFluentImpl.ParamRefNested<A> editOrNewParamRefLike(ParamRef item) {
    return withNewParamRefLike(getParamRef() != null ? getParamRef(): item);
  }
  public String getPolicyName() {
    return this.policyName;
  }
  public A withPolicyName(String policyName) {
    this.policyName=policyName; return (A) this;
  }
  public Boolean hasPolicyName() {
    return this.policyName != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ValidatingAdmissionPolicyBindingSpecFluentImpl that = (ValidatingAdmissionPolicyBindingSpecFluentImpl) o;
    if (!java.util.Objects.equals(matchResources, that.matchResources)) return false;

    if (!java.util.Objects.equals(paramRef, that.paramRef)) return false;

    if (!java.util.Objects.equals(policyName, that.policyName)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(matchResources,  paramRef,  policyName,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (matchResources != null) { sb.append("matchResources:"); sb.append(matchResources + ","); }
    if (paramRef != null) { sb.append("paramRef:"); sb.append(paramRef + ","); }
    if (policyName != null) { sb.append("policyName:"); sb.append(policyName + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class MatchResourcesNestedImpl<N> extends MatchResourcesFluentImpl<ValidatingAdmissionPolicyBindingSpecFluentImpl.MatchResourcesNested<N>> implements ValidatingAdmissionPolicyBindingSpecFluentImpl.MatchResourcesNested<N>,Nested<N>{
    MatchResourcesNestedImpl(MatchResources item) {
      this.builder = new MatchResourcesBuilder(this, item);
    }
    MatchResourcesNestedImpl() {
      this.builder = new MatchResourcesBuilder(this);
    }
    MatchResourcesBuilder builder;
    public N and() {
      return (N) ValidatingAdmissionPolicyBindingSpecFluentImpl.this.withMatchResources(builder.build());
    }
    public N endMatchResources() {
      return and();
    }
    
  }
  class ParamRefNestedImpl<N> extends ParamRefFluentImpl<ValidatingAdmissionPolicyBindingSpecFluentImpl.ParamRefNested<N>> implements ValidatingAdmissionPolicyBindingSpecFluentImpl.ParamRefNested<N>,Nested<N>{
    ParamRefNestedImpl(ParamRef item) {
      this.builder = new ParamRefBuilder(this, item);
    }
    ParamRefNestedImpl() {
      this.builder = new ParamRefBuilder(this);
    }
    ParamRefBuilder builder;
    public N and() {
      return (N) ValidatingAdmissionPolicyBindingSpecFluentImpl.this.withParamRef(builder.build());
    }
    public N endParamRef() {
      return and();
    }
    
  }
  
}
